CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                     C
C                            Pio (Fortran)                            C
C                                                                     C
C                    Polyglot Input/Output Library                    C
C                                                                     C
C               EPI Pomdapi, INRIA Paris - Rocquencourt               C
C                                                                     C
C  Copyright 2005-2014 INRIA.                                         C
C  Institut National de Recherche en Informatique et en Automatique.  C
C  All rights reserved. This file is distributed only by permission.  C
C                                                                     C
C  Francois Clement <Francois.Clement@inria.fr>                       C
C  Pierre Weis <Pierre.Weis@inria.fr>                                 C
C  Hend Ben Ameur <hbenameur@yahoo.ca>                                C
C                                                                     C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

C $Id: print_value_type.fpp,v 1.2 2014/01/10 19:22:10 fclement Exp $

C     
C     Routines to print the type of typed values.
C     
      
#include "pio_constants.h"
      
      subroutine print_simple_type(typ)
C     Print simple type typ.
      
      implicit none
      
C     Input argument.
      integer typ
      
C     Local variable.
      character sbr*17
      
C     External function.
      logical pio_communication_mode_is_binary
      
      sbr = 'print_simple_type'
      
      call buffer_print_char(sbr, '%')
      
      if (typ .eq. SSTRING) then
         
         call buffer_print_char(sbr, 'S')
         
      else if (typ .eq. SINT) then
         
         call buffer_print_char(sbr, 'i')
         
      else if (typ .eq. SFLOAT) then
         
         if (pio_communication_mode_is_binary()) then
            call buffer_print_string(sbr, 2, 'bf')
         else
            call buffer_print_char(sbr, 'f')
         endif
         
      else
         
C     impossible, already checked in print_scalar_type
         write(PIO_STDERR, *) 'typ = ', typ
         call error_internal_error(sbr)
         
      endif
      
      return
      end
      
      
      subroutine print_couple_type(typ)
C     Print couple type typ.
      
      implicit none
      
C     Input argument.
      integer typ
      
C     Local variables.
      character sbr*17
      integer item_typ
      
      sbr = 'print_couple_type'
      
      item_typ = MAKE_COUPLE_ITEM_TYPE(typ)
      
      call print_simple_type(item_typ)
      call buffer_print_string(sbr, 2, ', ')
      call print_simple_type(item_typ)
      
      return
      end
      
      
      subroutine print_triple_type(typ)
C     Print triple type typ.
      
      implicit none
      
C     Input argument.
      integer typ
      
C     Local variables.
      character sbr*17
      integer item_typ
      
      sbr = 'print_triple_type'
      
      item_typ = MAKE_TRIPLE_ITEM_TYPE(typ)
      
      call print_simple_type(item_typ)
      call buffer_print_string(sbr, 2, ', ')
      call print_simple_type(item_typ)
      call buffer_print_string(sbr, 2, ', ')
      call print_simple_type(item_typ)
      
      return
      end
      
      
      subroutine print_tuple_type(typ)
C     Print tuple type typ.
      
      implicit none
      
C     Input argument.
      integer typ
      
C     Local variables.
      character sbr*16
      
C     External functions.
      logical is_scalar_couple_type
      logical is_scalar_triple_type
      
      sbr = 'print_tuple_type'
      
      call buffer_print_char(sbr, '(')
      
      if (is_scalar_couple_type(typ)) then
         call print_couple_type(typ)
      else if (is_scalar_triple_type(typ)) then
         call print_triple_type(typ)
      else
         write(PIO_STDERR, *) 'typ = ', typ
         call error_assertion_failure(sbr,'wrong type checking.')
      endif
      
      call buffer_print_char(sbr, ')')
      
      return
      end
      
      
      subroutine print_scalar_type(typ)
C     Print scalar type typ.
      
      implicit none
      
C     Input argument.
      integer typ
      
C     Local variables.
      character sbr*17
      
C     External functions.
      logical is_scalar_simple_type
      logical is_scalar_tuple_type
      
      sbr = 'print_scalar_type'
      
      if (is_scalar_simple_type(typ)) then
         call print_simple_type(typ)
      else if (is_scalar_tuple_type(typ)) then
         call print_tuple_type(typ)
      else
         write(PIO_STDERR, *) 'typ = ', typ
         call error_assertion_failure(sbr,'wrong type checking.')
      endif
      
      return
      end
      
      
      subroutine print_vector_type(typ)
C     Print vector type typ.
      
      implicit none
      
C     Input argument.
      integer typ
      
C     Local variables.
      character sbr*17
      integer item_typ
      
      sbr = 'print_vector_type'
      
      item_typ = MAKE_VECTOR_ITEM_TYPE(typ)
      
      call buffer_print_natural(sbr, 1)
      call print_scalar_type(item_typ)
      call buffer_print_natural(sbr, 1)
      
      return
      end
       
      
      subroutine print_multi_d_type(i, typ)
C     Print multi_d type typ.
      
      implicit none
      
C     Input arguments.
      integer i, typ
      
C     Local variables.
      character sbr*16
      integer pv, item_typ
      
C     External function.
      integer fetch_value_dimension
      
      sbr = 'print_array_type'
      
      item_typ = MAKE_MULTI_D_ITEM_TYPE(typ)
      pv = fetch_value_dimension(sbr, PIO_OUT, i)
      
      call buffer_print_natural(sbr, pv)
      call print_scalar_type(item_typ)
      call buffer_print_natural(sbr, pv)
      
      return
      end
       
      
      subroutine print_array_type(i, typ)
C     Print array type typ.
      
      implicit none
      
C     Input arguments.
      integer i, typ
      
C     Local variable.
      character sbr*16
      
C     External functions.
      logical is_vector_type, is_multi_d_type
      
      sbr = 'print_array_type'
      
      call buffer_print_char(sbr, '[')
      
      if (is_vector_type(typ)) then
         call print_vector_type(typ)
      else if (is_multi_d_type(typ)) then
         call print_multi_d_type(i, typ)
      else
         write(PIO_STDERR, *) 'typ = ', typ
         call error_assertion_failure(sbr,'wrong type checking.')
      endif
      
      call buffer_print_char(sbr, ']')
      
      return
      end
     
      
      subroutine print_value_type(i, typ)
C     Print value type typ.
      
      implicit none
      
C     Input arguments.
      integer i, typ
      
C     Local variable.
      character sbr*16
      
C     External functions.
      logical is_scalar_type, is_array_type
      
      sbr = 'print_value_type'
      
      if (is_scalar_type(typ)) then
         call print_scalar_type(typ)
      else if (is_array_type(typ)) then
         call print_array_type(i, typ)
      else
         write(PIO_STDERR, *) 'typ = ', typ
         call error_assertion_failure(sbr,'wrong type checking.')
      endif
      
      return
      end
